# Extend the "do list" by one "layer" by adding elements to it.
# Deeper layers are indicated by uiCode equal to the range of line 
# numbers in 'tex' to further process.
# Only elements 'toDo' need be processed.
#
# Arguments:
#   doList: a linked list of lists which contain uiCode, serverCode, nextElement, and indent
#           The uiCode may be a character vector of Shiny code or a numeric vector of length
#           two which indicates the first and last 'tex' lines for further processing at a 
#           "deeper" level.
#   toDo: a logical vector indicating which elements of 'doList' need further processing
#   tex: the full LaTeX code (following shinyTex rules)
#
# Value:
#   an updated 'doList'
#
downOne = function(doList, toDo, tex, lineNumOffset) {
  for (eNum in which(toDo)) { # loop over (topmost) unexpanded elements and expand
    this = doList[[eNum]]
    if (this$uiCode[1]>this$uiCode[2]) { # adjacent begin/end{shinyTab}
      result = list(list(uiCode="HTML(' '),", serverCode=NA))
    } else {
      text = tex[this$uiCode[1]: this$uiCode[2]]
      if (length(grep("^[[:blank:]]*$", text, invert=TRUE))==0) { # empty shinyTab
        result = list(list(uiCode="HTML(' '),", serverCode=NA))
      } else {
        result = processTexRange(text, before=this$uiCode[1]-1, 
                                 indent=this$indent, eNum, lineNumOffset)
      }
    }
    resultLen = length(result)
    if (resultLen == 1) {
      doList[[eNum]]$uiCode = result[[1]]$uiCode
      doList[[eNum]]$serverCode = result[[1]]$serverCode
    } else {
      listLen = length(doList)
      doList[[eNum]] = result[[1]]
      doList[[eNum]]$nextElement = listLen + 1
      for (i in 2:resultLen) {
        index = listLen + i - 1
        doList[[index]] = result[[i]]
        doList[[index]]$nextElement = ifelse(i==resultLen, this$nextElement, index + 1)
      }
    }
  } # end for each (topmost) un-expanded element
  return(doList)
} # end downOne()
