# Description: construct a call in R to Shiny
# Input:
#   type: the shinyTex function type, e.g., shinySlider (used only for error messages)
#   funName: the Shiny function name for which a call is to be constructed
#   options: a named list comprising the arguments to pass to the function
#   required: a character vector containing the names of the required arguments for the function
#   requiredTypes: a character vector of types ('c','n','l', 'cv') matching 'required'
#   optional: a character vector containing the names of the optional arguments for the function
#   optionalTypes: a character vector of types ('c','n','l') matching 'optional'
#
# Value: a string containing a complete R-style function call (or other UI code) with approriate arguments
#
makeCall = function(type, funName, options, required, requiredTypes, 
                    optional, optionalTypes, lineNumOffset, defaults=NULL) {
  options = parseOptions(type, options, required, requiredTypes, 
                          optional, optionalTypes, lineNumOffset, defaults)

  optTxt = sapply(1:length(options), 
                  function(i) {
                    name = names(options)[i]
                    opt = options[[i]]
                    if (is.character(opt)) {
                      if (length(opt)==1) {
                        return(paste0(name, '="', opt, '"'))
                      } else {
                        return(paste0(name, '=c("',
                                      paste0(opt, collapse='", "'),
                                      '")'))
                      }
                    } else if (is.numeric(opt) && length(opt)>1) {
                      return(paste0(name, '=c(',
                                    paste0(opt, collapse=', '),
                                    ')'))
                      
                    } else {
                      paste0(name, '=', opt)
                    }
                  })
  str = paste0(funName, '(', paste(optTxt, collapse=', '), '),')
  
  return(str)
} # end makeCall()
