# Description: write the suffix code for a shinyTex environment, given the options
# Arguments:
#   environ: the name of the environment (e.g., shinySidePanel)
#   option: a single option, in string form, appropriate for the environment 
# Value: a string vector with Shiny ui code
#
suffixCode = function(environ, option) {
  if (environ == "shinySidePanel") {
    return(')),')
  } else if (environ == "shinyMainPanel") {
    return('),')
  } else if (environ == "shinyColumns") {
    return('),')
  } else if (environ == "shinyNextColumn") {
    return('),')
  } else if (environ == "shinyLastColumn") {
    return(')),')
  } else if (environ == "shinyNavbarMenu") {
    return(')')
  } else if (environ == "shinyEnumerate") {
    return('HTML("</ol>"),')
  } else if (environ == "shinyItemize") {
    return('HTML("</ul>"),')
  } else if (environ == "shinyConditionalPanel") {
    return('),')
  } else stop("suffix code does not handle ", environ)
}

## Write to ui.R and server.R
# Arguments:
#   txt: the text to be written
#   indent: the number of tabs to indent
#   tabSpaces: the number of spaces represented by each tab
#   new: TRUE=new file, FALSE=append
# Value: NULL
#
writeUi = function(txt, indent=0, tabSpaces=2, new=FALSE) {
  if (indent>0) txt = paste0(paste(rep(" ", indent*tabSpaces), collapse=""), txt)
  write(txt, file="ui.R", ncolumns=1, append=!new)
  return(NULL)
}
#
writeServer = function(txt, indent=0, tabSpaces=2, new=FALSE) {
  if (indent>0) txt = paste0(paste(rep(" ", indent*tabSpaces), collapse=""), txt)
  write(txt, file="server.R", ncolumns=1, append=!new)
  return(NULL)
}
